@@ -1,46 +1,65 @@
 <?php
-namespace Froxlor\Api\Commands;
-
-use Froxlor\Database\Database;
 
 /**
  * This file is part of the Froxlor project.
  * Copyright (c) 2010 the Froxlor Team (see authors).
  *
- * For the full copyright and license information, please view the COPYING
- * file that was distributed with this source code. You can also view the
- * COPYING file online at http://files.froxlor.org/misc/COPYING.txt
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
- * @copyright (c) the authors
- * @author Froxlor team <team@froxlor.org> (2010-)
- * @license GPLv2 http://files.froxlor.org/misc/COPYING.txt
- * @package API
- * @since 0.10.6
- *       
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, you can also view it online at
+ * https://files.froxlor.org/misc/COPYING.txt
+ *
+ * @copyright  the authors
+ * @author     Froxlor team <team@froxlor.org>
+ * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
-class SysLog extends \Froxlor\Api\ApiCommand implements \Froxlor\Api\ResourceEntity
+
+namespace Froxlor\Api\Commands;
+
+use Exception;
+use Froxlor\Api\ApiCommand;
+use Froxlor\Api\ResourceEntity;
+use Froxlor\Database\Database;
+use Froxlor\FroxlorLogger;
+use PDO;
+
+/**
+ * @since 0.10.6
+ */
+class SysLog extends ApiCommand implements ResourceEntity
 {
 
 	/**
 	 * list all log-entries
 	 *
 	 * @param array $sql_search
-	 *        	optional array with index = fieldname, and value = array with 'op' => operator (one of <, > or =), LIKE is used if left empty and 'value' => searchvalue
+	 *            optional array with index = fieldname, and value = array with 'op' => operator (one of <, > or =),
+	 *            LIKE is used if left empty and 'value' => searchvalue
 	 * @param int $sql_limit
-	 *        	optional specify number of results to be returned
+	 *            optional specify number of results to be returned
 	 * @param int $sql_offset
-	 *        	optional specify offset for resultset
+	 *            optional specify offset for resultset
 	 * @param array $sql_orderby
-	 *        	optional array with index = fieldname and value = ASC|DESC to order the resultset by one or more fields
-	 *        	
+	 *            optional array with index = fieldname and value = ASC|DESC to order the resultset by one or more
+	 *            fields
+	 *
 	 * @access admin, customer
-	 * @throws \Exception
 	 * @return string json-encoded array count|list
+	 * @throws Exception
 	 */
 	public function listing()
 	{
-		$result = array();
-		$query_fields = array();
+		$result = [];
+		$query_fields = [];
 		if ($this->isAdmin() && $this->getUserDetail('customers_see_all') == '1') {
 			$result_stmt = Database::prepare("
 			SELECT * FROM `" . TABLE_PANEL_LOG . "` " . $this->getSearchWhere($query_fields) . $this->getOrderBy() . $this->getLimit());
@@ -48,7 +67,7 @@ class SysLog extends \Froxlor\Api\ApiCommand implements \Froxlor\Api\ResourceEnt
 			// get all admin customers
 			$_custom_list_result = $this->apiCall('Customers.listing');
 			$custom_list_result = $_custom_list_result['list'];
-			$customer_names = array();
+			$customer_names = [];
 			foreach ($custom_list_result as $customer) {
 				$customer_names[] = $customer['loginname'];
 			}
@@ -70,22 +89,22 @@ class SysLog extends \Froxlor\Api\ApiCommand implements \Froxlor\Api\ResourceEnt
 			$query_fields['loginname'] = $this->getUserDetail('loginname');
 		}
 		Database::pexecute($result_stmt, $query_fields, true, true);
-		while ($row = $result_stmt->fetch(\PDO::FETCH_ASSOC)) {
+		while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
 			$result[] = $row;
 		}
-		$this->logger()->logAction($this->isAdmin() ? \Froxlor\FroxlorLogger::ADM_ACTION : \Froxlor\FroxlorLogger::USR_ACTION, LOG_NOTICE, "[API] list log-entries");
-		return $this->response(200, "successful", array(
+		$this->logger()->logAction($this->isAdmin() ? FroxlorLogger::ADM_ACTION : FroxlorLogger::USR_ACTION, LOG_NOTICE, "[API] list log-entries");
+		return $this->response([
 			'count' => count($result),
 			'list' => $result
-		));
+		]);
 	}
 
 	/**
 	 * returns the total number of log-entries
 	 *
 	 * @access admin
-	 * @throws \Exception
-	 * @return string json-encoded array
+	 * @return string json-encoded response message
+	 * @throws Exception
 	 */
 	public function listingCount()
 	{
@@ -98,7 +117,7 @@ class SysLog extends \Froxlor\Api\ApiCommand implements \Froxlor\Api\ResourceEnt
 			// get all admin customers
 			$_custom_list_result = $this->apiCall('Customers.listing');
 			$custom_list_result = $_custom_list_result['list'];
-			$customer_names = array();
+			$customer_names = [];
 			foreach ($custom_list_result as $customer) {
 				$customer_names[] = $customer['loginname'];
 			}
@@ -129,8 +148,9 @@ class SysLog extends \Froxlor\Api\ApiCommand implements \Froxlor\Api\ResourceEnt
 
 		$result = Database::pexecute_first($result_stmt, $params, true, true);
 		if ($result) {
-			return $this->response(200, "successful", $result['num_logs']);
+			return $this->response($result['num_logs']);
 		}
+		return $this->response(0);
 	}
 
 	/**
@@ -138,7 +158,7 @@ class SysLog extends \Froxlor\Api\ApiCommand implements \Froxlor\Api\ResourceEnt
 	 */
 	public function get()
 	{
-		throw new \Exception('You cannot get log entries', 303);
+		throw new Exception('You cannot get log entries', 303);
 	}
 
 	/**
@@ -146,7 +166,7 @@ class SysLog extends \Froxlor\Api\ApiCommand implements \Froxlor\Api\ResourceEnt
 	 */
 	public function add()
 	{
-		throw new \Exception('You cannot add log entries', 303);
+		throw new Exception('You cannot add log entries', 303);
 	}
 
 	/**
@@ -154,18 +174,18 @@ class SysLog extends \Froxlor\Api\ApiCommand implements \Froxlor\Api\ResourceEnt
 	 */
 	public function update()
 	{
-		throw new \Exception('You cannot update log entries', 303);
+		throw new Exception('You cannot update log entries', 303);
 	}
 
 	/**
 	 * delete log entries
 	 *
 	 * @param int $min_to_keep
-	 *        	optional minutes to keep, default is 10
-	 *        	
+	 *            optional minutes to keep, default is 10
+	 *
 	 * @access admin
-	 * @throws \Exception
 	 * @return string json-encoded array
+	 * @throws Exception
 	 */
 	public function delete()
 	{
@@ -175,7 +195,7 @@ class SysLog extends \Froxlor\Api\ApiCommand implements \Froxlor\Api\ResourceEnt
 				$min_to_keep = 0;
 			}
 			$truncatedate = time() - (60 * $min_to_keep);
-			$params = array();
+			$params = [];
 			if ($this->getUserDetail('customers_see_all') == '1') {
 				$result_stmt = Database::prepare("
 					DELETE FROM `" . TABLE_PANEL_LOG . "` WHERE `date` < :trunc
@@ -184,7 +204,7 @@ class SysLog extends \Froxlor\Api\ApiCommand implements \Froxlor\Api\ResourceEnt
 				// get all admin customers
 				$_custom_list_result = $this->apiCall('Customers.listing');
 				$custom_list_result = $_custom_list_result['list'];
-				$customer_names = array();
+				$customer_names = [];
 				foreach ($custom_list_result as $customer) {
 					$customer_names[] = $customer['loginname'];
 				}
@@ -203,9 +223,9 @@ class SysLog extends \Froxlor\Api\ApiCommand implements \Froxlor\Api\ResourceEnt
 			}
 			$params['trunc'] = $truncatedate;
 			Database::pexecute($result_stmt, $params, true, true);
-			$this->logger()->logAction($this->isAdmin() ? \Froxlor\FroxlorLogger::ADM_ACTION : \Froxlor\FroxlorLogger::USR_ACTION, LOG_WARNING, "[API] truncated the froxlor syslog");
-			return $this->response(200, "successful", true);
+			$this->logger()->logAction($this->isAdmin() ? FroxlorLogger::ADM_ACTION : FroxlorLogger::USR_ACTION, LOG_WARNING, "[API] truncated the froxlor syslog");
+			return $this->response(true);
 		}
-		throw new \Exception("Not allowed to execute given command.", 403);
+		throw new Exception("Not allowed to execute given command.", 403);
 	}
 }
